/*
 * blocks.c
 *
 * Public information from https://www.unicode.org/Public/UNIDATA/Blocks.txt
 * Copyright information about see at https://www.unicode.org/copyright.html
 */

#include <wchar.h>
#include "mimelang.h"

const unicode_block_t blocks[] = {
	{ 0x0000, 0x007F, MIME_UTF8|MIME_LATIN, "Basic Latin" },
	{ 0x0080, 0x00FF, MIME_UTF8|MIME_LATIN, "Latin-1 Supplement" },
	{ 0x0100, 0x017F, MIME_UTF8|MIME_LATIN, "Latin Extended-A" },
	{ 0x0180, 0x024F, MIME_UTF8|MIME_LATIN, "Latin Extended-B" },
	{ 0x0250, 0x02AF, MIME_UTF8|MIME_LATIN, "IPA Extensions" },
	{ 0x02B0, 0x02FF, MIME_UTF8|MIME_LATIN, "Spacing Modifier Letters" },
	{ 0x0300, 0x036F, MIME_UTF8|MIME_LATIN, "Combining Diacritical Marks" },
	{ 0x0370, 0x03FF, MIME_UTF8, "Greek and Coptic" },
	{ 0x0400, 0x04FF, MIME_UTF8, "Cyrillic" },
	{ 0x0500, 0x052F, MIME_UTF8, "Cyrillic Supplement" },
	{ 0x0530, 0x058F, MIME_UTF8, "Armenian" },
	{ 0x0590, 0x05FF, MIME_UTF8|MIME_NONEU, "Hebrew" },
	{ 0x0600, 0x06FF, MIME_UTF8|MIME_NONEU, "Arabic" },
	{ 0x0700, 0x074F, MIME_UTF8|MIME_NONEU, "Syriac" },
	{ 0x0750, 0x077F, MIME_UTF8|MIME_NONEU, "Arabic Supplement" },
	{ 0x0780, 0x07BF, MIME_UTF8|MIME_NONEU, "Thaana" },
	{ 0x07C0, 0x07FF, MIME_UTF8|MIME_NONEU, "NKo" },
	{ 0x0800, 0x083F, MIME_UTF8|MIME_NONEU, "Samaritan" },
	{ 0x0840, 0x085F, MIME_UTF8|MIME_NONEU, "Mandaic" },
	{ 0x0860, 0x086F, MIME_UTF8|MIME_NONEU, "Syriac Supplement" },
	{ 0x08A0, 0x08FF, MIME_UTF8|MIME_NONEU, "Arabic Extended-A" },
	{ 0x0900, 0x097F, MIME_UTF8|MIME_NONEU, "Devanagari" },
	{ 0x0980, 0x09FF, MIME_UTF8|MIME_NONEU, "Bengali" },
	{ 0x0A00, 0x0A7F, MIME_UTF8|MIME_NONEU, "Gurmukhi" },
	{ 0x0A80, 0x0AFF, MIME_UTF8|MIME_NONEU, "Gujarati" },
	{ 0x0B00, 0x0B7F, MIME_UTF8|MIME_NONEU, "Oriya" },
	{ 0x0B80, 0x0BFF, MIME_UTF8|MIME_NONEU, "Tamil" },
	{ 0x0C00, 0x0C7F, MIME_UTF8|MIME_NONEU, "Telugu" },
	{ 0x0C80, 0x0CFF, MIME_UTF8|MIME_NONEU, "Kannada" },
	{ 0x0D00, 0x0D7F, MIME_UTF8|MIME_NONEU, "Malayalam" },
	{ 0x0D80, 0x0DFF, MIME_UTF8|MIME_NONEU, "Sinhala" },
	{ 0x0E00, 0x0E7F, MIME_UTF8|MIME_NONEU, "Thai" },
	{ 0x0E80, 0x0EFF, MIME_UTF8|MIME_NONEU, "Lao" },
	{ 0x0F00, 0x0FFF, MIME_UTF8|MIME_NONEU, "Tibetan" },
	{ 0x1000, 0x109F, MIME_UTF8|MIME_NONEU, "Myanmar" },
	{ 0x10A0, 0x10FF, MIME_UTF8, "Georgian" },
	{ 0x1100, 0x11FF, MIME_UTF8|MIME_NONEU, "Hangul Jamo" },
	{ 0x1200, 0x137F, MIME_UTF8|MIME_NONEU, "Ethiopic" },
	{ 0x1380, 0x139F, MIME_UTF8|MIME_NONEU, "Ethiopic Supplement" },
	{ 0x13A0, 0x13FF, MIME_UTF8|MIME_NONEU, "Cherokee" },
	{ 0x1400, 0x167F, MIME_UTF8, "Unified Canadian Aboriginal Syllabics" },
	{ 0x1680, 0x169F, MIME_UTF8|MIME_NONEU, "Ogham" },
	{ 0x16A0, 0x16FF, MIME_UTF8|MIME_NONEU, "Runic" },
	{ 0x1700, 0x171F, MIME_UTF8|MIME_NONEU, "Tagalog" },
	{ 0x1720, 0x173F, MIME_UTF8|MIME_NONEU, "Hanunoo" },
	{ 0x1740, 0x175F, MIME_UTF8|MIME_NONEU, "Buhid" },
	{ 0x1760, 0x177F, MIME_UTF8|MIME_NONEU, "Tagbanwa" },
	{ 0x1780, 0x17FF, MIME_UTF8|MIME_NONEU, "Khmer" },
	{ 0x1800, 0x18AF, MIME_UTF8|MIME_NONEU, "Mongolian" },
	{ 0x18B0, 0x18FF, MIME_UTF8, "Unified Canadian Aboriginal Syllabics Extended" },
	{ 0x1900, 0x194F, MIME_UTF8|MIME_NONEU, "Limbu" },
	{ 0x1950, 0x197F, MIME_UTF8|MIME_NONEU, "Tai Le" },
	{ 0x1980, 0x19DF, MIME_UTF8|MIME_NONEU, "New Tai Lue" },
	{ 0x19E0, 0x19FF, MIME_UTF8|MIME_NONEU, "Khmer Symbols" },
	{ 0x1A00, 0x1A1F, MIME_UTF8|MIME_NONEU, "Buginese" },
	{ 0x1A20, 0x1AAF, MIME_UTF8|MIME_NONEU, "Tai Tham" },
	{ 0x1AB0, 0x1AFF, MIME_UTF8|MIME_SYMBOL, "Combining Diacritical Marks Extended" },
	{ 0x1B00, 0x1B7F, MIME_UTF8|MIME_NONEU, "Balinese" },
	{ 0x1B80, 0x1BBF, MIME_UTF8|MIME_NONEU, "Sundanese" },
	{ 0x1BC0, 0x1BFF, MIME_UTF8|MIME_NONEU, "Batak" },
	{ 0x1C00, 0x1C4F, MIME_UTF8|MIME_NONEU, "Lepcha" },
	{ 0x1C50, 0x1C7F, MIME_UTF8|MIME_NONEU, "Ol Chiki" },
	{ 0x1C80, 0x1C8F, MIME_UTF8, "Cyrillic Extended-C" },
	{ 0x1C90, 0x1CBF, MIME_UTF8, "Georgian Extended" },
	{ 0x1CC0, 0x1CCF, MIME_UTF8|MIME_NONEU, "Sundanese Supplement" },
	{ 0x1CD0, 0x1CFF, MIME_UTF8|MIME_LATIN, "Vedic Extensions" },
	{ 0x1D00, 0x1D7F, MIME_UTF8|MIME_SYMBOL, "Phonetic Extensions" },
	{ 0x1D80, 0x1DBF, MIME_UTF8|MIME_SYMBOL, "Phonetic Extensions Supplement" },
	{ 0x1DC0, 0x1DFF, MIME_UTF8|MIME_SYMBOL, "Combining Diacritical Marks Supplement" },
	{ 0x1E00, 0x1EFF, MIME_UTF8|MIME_LATIN, "Latin Extended Additional" },
	{ 0x1F00, 0x1FFF, MIME_UTF8|MIME_LATIN, "Greek Extended" },
	{ 0x2000, 0x206F, MIME_UTF8|MIME_SYMBOL, "General Punctuation" },
	{ 0x2070, 0x209F, MIME_UTF8|MIME_SYMBOL, "Superscripts and Subscripts" },
	{ 0x20A0, 0x20CF, MIME_UTF8|MIME_SYMBOL, "Currency Symbols" },
	{ 0x20D0, 0x20FF, MIME_UTF8|MIME_SYMBOL, "Combining Diacritical Marks for Symbols" },
	{ 0x2100, 0x214F, MIME_UTF8|MIME_SYMBOL, "Letterlike Symbols" },
	{ 0x2150, 0x218F, MIME_UTF8|MIME_SYMBOL, "Number Forms" },
	{ 0x2190, 0x21FF, MIME_UTF8|MIME_SYMBOL, "Arrows" },
	{ 0x2200, 0x22FF, MIME_UTF8|MIME_SYMBOL, "Mathematical Operators" },
	{ 0x2300, 0x23FF, MIME_UTF8|MIME_SYMBOL, "Miscellaneous Technical" },
	{ 0x2400, 0x243F, MIME_UTF8|MIME_SYMBOL, "Control Pictures" },
	{ 0x2440, 0x245F, MIME_UTF8|MIME_SYMBOL, "Optical Character Recognition" },
	{ 0x2460, 0x24FF, MIME_UTF8|MIME_SYMBOL, "Enclosed Alphanumerics" },
	{ 0x2500, 0x257F, MIME_UTF8|MIME_SYMBOL, "Box Drawing" },
	{ 0x2580, 0x259F, MIME_UTF8|MIME_SYMBOL, "Block Elements" },
	{ 0x25A0, 0x25FF, MIME_UTF8|MIME_SYMBOL, "Geometric Shapes" },
	{ 0x2600, 0x26FF, MIME_UTF8|MIME_SYMBOL, "Miscellaneous Symbols" },
	{ 0x2700, 0x27BF, MIME_UTF8|MIME_SYMBOL, "Dingbats" },
	{ 0x27C0, 0x27EF, MIME_UTF8|MIME_SYMBOL, "Miscellaneous Mathematical Symbols-A" },
	{ 0x27F0, 0x27FF, MIME_UTF8|MIME_SYMBOL, "Supplemental Arrows-A" },
	{ 0x2800, 0x28FF, MIME_UTF8, "Braille Patterns" },
	{ 0x2900, 0x297F, MIME_UTF8|MIME_SYMBOL, "Supplemental Arrows-B" },
	{ 0x2980, 0x29FF, MIME_UTF8|MIME_SYMBOL, "Miscellaneous Mathematical Symbols-B" },
	{ 0x2A00, 0x2AFF, MIME_UTF8|MIME_SYMBOL, "Supplemental Mathematical Operators" },
	{ 0x2B00, 0x2BFF, MIME_UTF8|MIME_SYMBOL, "Miscellaneous Symbols and Arrows" },
	{ 0x2C00, 0x2C5F, MIME_UTF8, "Glagolitic" },
	{ 0x2C60, 0x2C7F, MIME_UTF8|MIME_LATIN, "Latin Extended-C" },
	{ 0x2C80, 0x2CFF, MIME_UTF8, "Coptic" },
	{ 0x2D00, 0x2D2F, MIME_UTF8, "Georgian Supplement" },
	{ 0x2D30, 0x2D7F, MIME_UTF8|MIME_NONEU, "Tifinagh" },
	{ 0x2D80, 0x2DDF, MIME_UTF8|MIME_NONEU, "Ethiopic Extended" },
	{ 0x2DE0, 0x2DFF, MIME_UTF8, "Cyrillic Extended-A" },
	{ 0x2E00, 0x2E7F, MIME_UTF8, "Supplemental Punctuation" },
	{ 0x2E80, 0x2EFF, MIME_UTF8|MIME_NONEU, "CJK Radicals Supplement" },
	{ 0x2F00, 0x2FDF, MIME_UTF8|MIME_NONEU, "Kangxi Radicals" },
	{ 0x2FF0, 0x2FFF, MIME_UTF8|MIME_NONEU, "Ideographic Description Characters" },
	{ 0x3000, 0x303F, MIME_UTF8|MIME_NONEU, "CJK Symbols and Punctuation" },
	{ 0x3040, 0x309F, MIME_UTF8|MIME_NONEU, "Hiragana" },
	{ 0x30A0, 0x30FF, MIME_UTF8|MIME_NONEU, "Katakana" },
	{ 0x3100, 0x312F, MIME_UTF8|MIME_NONEU, "Bopomofo" },
	{ 0x3130, 0x318F, MIME_UTF8|MIME_NONEU, "Hangul Compatibility Jamo" },
	{ 0x3190, 0x319F, MIME_UTF8|MIME_NONEU, "Kanbun" },
	{ 0x31A0, 0x31BF, MIME_UTF8|MIME_NONEU, "Bopomofo Extended" },
	{ 0x31C0, 0x31EF, MIME_UTF8|MIME_NONEU, "CJK Strokes" },
	{ 0x31F0, 0x31FF, MIME_UTF8|MIME_NONEU, "Katakana Phonetic Extensions" },
	{ 0x3200, 0x32FF, MIME_UTF8|MIME_NONEU, "Enclosed CJK Letters and Months" },
	{ 0x3300, 0x33FF, MIME_UTF8|MIME_NONEU, "CJK Compatibility" },
	{ 0x3400, 0x4DBF, MIME_UTF8|MIME_NONEU, "CJK Unified Ideographs Extension A" },
	{ 0x4DC0, 0x4DFF, MIME_UTF8|MIME_NONEU, "Yijing Hexagram Symbols" },
	{ 0x4E00, 0x9FFF, MIME_UTF8|MIME_NONEU, "CJK Unified Ideographs" },
	{ 0xA000, 0xA48F, MIME_UTF8|MIME_NONEU, "Yi Syllables" },
	{ 0xA490, 0xA4CF, MIME_UTF8|MIME_NONEU, "Yi Radicals" },
	{ 0xA4D0, 0xA4FF, MIME_UTF8|MIME_NONEU, "Lisu" },
	{ 0xA500, 0xA63F, MIME_UTF8|MIME_NONEU, "Vai" },
	{ 0xA640, 0xA69F, MIME_UTF8, "Cyrillic Extended-B" },
	{ 0xA6A0, 0xA6FF, MIME_UTF8|MIME_NONEU, "Bamum" },
	{ 0xA700, 0xA71F, MIME_UTF8|MIME_LATIN, "Modifier Tone Letters" },
	{ 0xA720, 0xA7FF, MIME_UTF8|MIME_LATIN, "Latin Extended-D" },
	{ 0xA800, 0xA82F, MIME_UTF8|MIME_NONEU, "Syloti Nagri" },
	{ 0xA830, 0xA83F, MIME_UTF8|MIME_NONEU, "Common Indic Number Forms" },
	{ 0xA840, 0xA87F, MIME_UTF8|MIME_NONEU, "Phags-pa" },
	{ 0xA880, 0xA8DF, MIME_UTF8|MIME_NONEU, "Saurashtra" },
	{ 0xA8E0, 0xA8FF, MIME_UTF8|MIME_NONEU, "Devanagari Extended" },
	{ 0xA900, 0xA92F, MIME_UTF8|MIME_NONEU, "Kayah Li" },
	{ 0xA930, 0xA95F, MIME_UTF8|MIME_NONEU, "Rejang" },
	{ 0xA960, 0xA97F, MIME_UTF8|MIME_NONEU, "Hangul Jamo Extended-A" },
	{ 0xA980, 0xA9DF, MIME_UTF8|MIME_NONEU, "Javanese" },
	{ 0xA9E0, 0xA9FF, MIME_UTF8|MIME_NONEU, "Myanmar Extended-B" },
	{ 0xAA00, 0xAA5F, MIME_UTF8|MIME_NONEU, "Cham" },
	{ 0xAA60, 0xAA7F, MIME_UTF8|MIME_NONEU, "Myanmar Extended-A" },
	{ 0xAA80, 0xAADF, MIME_UTF8|MIME_NONEU, "Tai Viet" },
	{ 0xAAE0, 0xAAFF, MIME_UTF8|MIME_NONEU, "Meetei Mayek Extensions" },
	{ 0xAB00, 0xAB2F, MIME_UTF8|MIME_NONEU, "Ethiopic Extended-A" },
	{ 0xAB30, 0xAB6F, MIME_UTF8|MIME_LATIN, "Latin Extended-E" },
	{ 0xAB70, 0xABBF, MIME_UTF8|MIME_NONEU, "Cherokee Supplement" },
	{ 0xABC0, 0xABFF, MIME_UTF8|MIME_NONEU, "Meetei Mayek" },
	{ 0xAC00, 0xD7AF, MIME_UTF8|MIME_NONEU, "Hangul Syllables" },
	{ 0xD7B0, 0xD7FF, MIME_UTF8|MIME_NONEU, "Hangul Jamo Extended-B" },
	{ 0xD800, 0xDB7F, MIME_UTF8|MIME_SYMBOL, "High Surrogates" },
	{ 0xDB80, 0xDBFF, MIME_UTF8|MIME_SYMBOL, "High Private Use Surrogates" },
	{ 0xDC00, 0xDFFF, MIME_UTF8|MIME_SYMBOL, "Low Surrogates" },
	{ 0xE000, 0xF8FF, MIME_UTF8|MIME_SYMBOL, "Private Use Area" },
	{ 0xF900, 0xFAFF, MIME_UTF8|MIME_NONEU, "CJK Compatibility Ideographs" },
	{ 0xFB00, 0xFB4F, MIME_UTF8, "Alphabetic Presentation Forms" },
	{ 0xFB50, 0xFDFF, MIME_UTF8|MIME_NONEU, "Arabic Presentation Forms-A" },
	{ 0xFE00, 0xFE0F, MIME_UTF8|MIME_SYMBOL, "Variation Selectors" },
	{ 0xFE10, 0xFE1F, MIME_UTF8|MIME_SYMBOL, "Vertical Forms" },
	{ 0xFE20, 0xFE2F, MIME_UTF8|MIME_SYMBOL, "Combining Half Marks" },
	{ 0xFE30, 0xFE4F, MIME_UTF8|MIME_NONEU, "CJK Compatibility Forms" },
	{ 0xFE50, 0xFE6F, MIME_UTF8|MIME_SYMBOL, "Small Form Variants" },
	{ 0xFE70, 0xFEFF, MIME_UTF8|MIME_NONEU, "Arabic Presentation Forms-B" },
	{ 0xFF00, 0xFFEF, MIME_UTF8|MIME_SYMBOL, "Halfwidth and Fullwidth Forms" },
	{ 0xFFF0, 0xFFFF, MIME_UTF8|MIME_SYMBOL, "Specials" },
	{ 0x10000, 0x1007F, MIME_UTF8|MIME_SYMBOL, "Linear B Syllabary" },
	{ 0x10080, 0x100FF, MIME_UTF8|MIME_SYMBOL, "Linear B Ideograms" },
	{ 0x10100, 0x1013F, MIME_UTF8, "Aegean Numbers" },
	{ 0x10140, 0x1018F, MIME_UTF8, "Ancient Greek Numbers" },
	{ 0x10190, 0x101CF, MIME_UTF8|MIME_SYMBOL, "Ancient Symbols" },
	{ 0x101D0, 0x101FF, MIME_UTF8|MIME_NONEU, "Phaistos Disc" },
	{ 0x10280, 0x1029F, MIME_UTF8|MIME_NONEU, "Lycian" },
	{ 0x102A0, 0x102DF, MIME_UTF8|MIME_NONEU, "Carian" },
	{ 0x102E0, 0x102FF, MIME_UTF8, "Coptic Epact Numbers" },
	{ 0x10300, 0x1032F, MIME_UTF8, "Old Italic" },
	{ 0x10330, 0x1034F, MIME_UTF8, "Gothic" },
	{ 0x10350, 0x1037F, MIME_UTF8|MIME_NONEU, "Old Permic" },
	{ 0x10380, 0x1039F, MIME_UTF8|MIME_NONEU, "Ugaritic" },
	{ 0x103A0, 0x103DF, MIME_UTF8|MIME_NONEU, "Old Persian" },
	{ 0x10400, 0x1044F, MIME_UTF8|MIME_NONEU, "Deseret" },
	{ 0x10450, 0x1047F, MIME_UTF8|MIME_NONEU, "Shavian" },
	{ 0x10480, 0x104AF, MIME_UTF8|MIME_NONEU, "Osmanya" },
	{ 0x104B0, 0x104FF, MIME_UTF8|MIME_NONEU, "Osage" },
	{ 0x10500, 0x1052F, MIME_UTF8|MIME_NONEU, "Elbasan" },
	{ 0x10530, 0x1056F, MIME_UTF8, "Caucasian Albanian" },
	{ 0x10600, 0x1077F, MIME_UTF8|MIME_SYMBOL, "Linear A" },
	{ 0x10800, 0x1083F, MIME_UTF8, "Cypriot Syllabary" },
	{ 0x10840, 0x1085F, MIME_UTF8|MIME_NONEU, "Imperial Aramaic" },
	{ 0x10860, 0x1087F, MIME_UTF8|MIME_NONEU, "Palmyrene" },
	{ 0x10880, 0x108AF, MIME_UTF8|MIME_NONEU, "Nabataean" },
	{ 0x108E0, 0x108FF, MIME_UTF8|MIME_NONEU, "Hatran" },
	{ 0x10900, 0x1091F, MIME_UTF8|MIME_NONEU, "Phoenician" },
	{ 0x10920, 0x1093F, MIME_UTF8|MIME_NONEU, "Lydian" },
	{ 0x10980, 0x1099F, MIME_UTF8|MIME_NONEU, "Meroitic Hieroglyphs" },
	{ 0x109A0, 0x109FF, MIME_UTF8|MIME_NONEU, "Meroitic Cursive" },
	{ 0x10A00, 0x10A5F, MIME_UTF8|MIME_NONEU, "Kharoshthi" },
	{ 0x10A60, 0x10A7F, MIME_UTF8|MIME_NONEU, "Old South Arabian" },
	{ 0x10A80, 0x10A9F, MIME_UTF8|MIME_NONEU, "Old North Arabian" },
	{ 0x10AC0, 0x10AFF, MIME_UTF8|MIME_NONEU, "Manichaean" },
	{ 0x10B00, 0x10B3F, MIME_UTF8|MIME_NONEU, "Avestan" },
	{ 0x10B40, 0x10B5F, MIME_UTF8|MIME_NONEU, "Inscriptional Parthian" },
	{ 0x10B60, 0x10B7F, MIME_UTF8|MIME_NONEU, "Inscriptional Pahlavi" },
	{ 0x10B80, 0x10BAF, MIME_UTF8|MIME_NONEU, "Psalter Pahlavi" },
	{ 0x10C00, 0x10C4F, MIME_UTF8|MIME_NONEU, "Old Turkic" },
	{ 0x10C80, 0x10CFF, MIME_UTF8, "Old Hungarian" },
	{ 0x10D00, 0x10D3F, MIME_UTF8|MIME_NONEU, "Hanifi Rohingya" },
	{ 0x10E60, 0x10E7F, MIME_UTF8|MIME_NONEU, "Rumi Numeral Symbols" },
	{ 0x10E80, 0x10EBF, MIME_UTF8|MIME_NONEU, "Yezidi" },
	{ 0x10F00, 0x10F2F, MIME_UTF8|MIME_NONEU, "Old Sogdian" },
	{ 0x10F30, 0x10F6F, MIME_UTF8|MIME_NONEU, "Sogdian" },
	{ 0x10FB0, 0x10FDF, MIME_UTF8|MIME_NONEU, "Chorasmian" },
	{ 0x10FE0, 0x10FFF, MIME_UTF8|MIME_NONEU, "Elymaic" },
	{ 0x11000, 0x1107F, MIME_UTF8|MIME_NONEU, "Brahmi" },
	{ 0x11080, 0x110CF, MIME_UTF8|MIME_NONEU, "Kaithi" },
	{ 0x110D0, 0x110FF, MIME_UTF8|MIME_NONEU, "Sora Sompeng" },
	{ 0x11100, 0x1114F, MIME_UTF8|MIME_NONEU, "Chakma" },
	{ 0x11150, 0x1117F, MIME_UTF8|MIME_NONEU, "Mahajani" },
	{ 0x11180, 0x111DF, MIME_UTF8|MIME_NONEU, "Sharada" },
	{ 0x111E0, 0x111FF, MIME_UTF8|MIME_NONEU, "Sinhala Archaic Numbers" },
	{ 0x11200, 0x1124F, MIME_UTF8|MIME_NONEU, "Khojki" },
	{ 0x11280, 0x112AF, MIME_UTF8|MIME_NONEU, "Multani" },
	{ 0x112B0, 0x112FF, MIME_UTF8|MIME_NONEU, "Khudawadi" },
	{ 0x11300, 0x1137F, MIME_UTF8|MIME_NONEU, "Grantha" },
	{ 0x11400, 0x1147F, MIME_UTF8|MIME_NONEU, "Newa" },
	{ 0x11480, 0x114DF, MIME_UTF8|MIME_NONEU, "Tirhuta" },
	{ 0x11580, 0x115FF, MIME_UTF8|MIME_NONEU, "Siddham" },
	{ 0x11600, 0x1165F, MIME_UTF8|MIME_NONEU, "Modi" },
	{ 0x11660, 0x1167F, MIME_UTF8|MIME_NONEU, "Mongolian Supplement" },
	{ 0x11680, 0x116CF, MIME_UTF8|MIME_NONEU, "Takri" },
	{ 0x11700, 0x1173F, MIME_UTF8|MIME_NONEU, "Ahom" },
	{ 0x11800, 0x1184F, MIME_UTF8|MIME_NONEU, "Dogra" },
	{ 0x118A0, 0x118FF, MIME_UTF8|MIME_NONEU, "Warang Citi" },
	{ 0x11900, 0x1195F, MIME_UTF8|MIME_NONEU, "Dives Akuru" },
	{ 0x119A0, 0x119FF, MIME_UTF8|MIME_NONEU, "Nandinagari" },
	{ 0x11A00, 0x11A4F, MIME_UTF8|MIME_NONEU, "Zanabazar Square" },
	{ 0x11A50, 0x11AAF, MIME_UTF8|MIME_NONEU, "Soyombo" },
	{ 0x11AC0, 0x11AFF, MIME_UTF8|MIME_NONEU, "Pau Cin Hau" },
	{ 0x11C00, 0x11C6F, MIME_UTF8|MIME_NONEU, "Bhaiksuki" },
	{ 0x11C70, 0x11CBF, MIME_UTF8|MIME_NONEU, "Marchen" },
	{ 0x11D00, 0x11D5F, MIME_UTF8|MIME_NONEU, "Masaram Gondi" },
	{ 0x11D60, 0x11DAF, MIME_UTF8|MIME_NONEU, "Gunjala Gondi" },
	{ 0x11EE0, 0x11EFF, MIME_UTF8|MIME_NONEU, "Makasar" },
	{ 0x11FB0, 0x11FBF, MIME_UTF8|MIME_NONEU, "Lisu Supplement" },
	{ 0x11FC0, 0x11FFF, MIME_UTF8|MIME_NONEU, "Tamil Supplement" },
	{ 0x12000, 0x123FF, MIME_UTF8|MIME_NONEU, "Cuneiform" },
	{ 0x12400, 0x1247F, MIME_UTF8|MIME_NONEU, "Cuneiform Numbers and Punctuation" },
	{ 0x12480, 0x1254F, MIME_UTF8|MIME_NONEU, "Early Dynastic Cuneiform" },
	{ 0x13000, 0x1342F, MIME_UTF8|MIME_NONEU, "Egyptian Hieroglyphs" },
	{ 0x13430, 0x1343F, MIME_UTF8|MIME_NONEU, "Egyptian Hieroglyph Format Controls" },
	{ 0x14400, 0x1467F, MIME_UTF8|MIME_NONEU, "Anatolian Hieroglyphs" },
	{ 0x16800, 0x16A3F, MIME_UTF8|MIME_NONEU, "Bamum Supplement" },
	{ 0x16A40, 0x16A6F, MIME_UTF8|MIME_NONEU, "Mro" },
	{ 0x16AD0, 0x16AFF, MIME_UTF8|MIME_NONEU, "Bassa Vah" },
	{ 0x16B00, 0x16B8F, MIME_UTF8|MIME_NONEU, "Pahawh Hmong" },
	{ 0x16E40, 0x16E9F, MIME_UTF8|MIME_NONEU, "Medefaidrin" },
	{ 0x16F00, 0x16F9F, MIME_UTF8|MIME_NONEU, "Miao" },
	{ 0x16FE0, 0x16FFF, MIME_UTF8|MIME_SYMBOL, "Ideographic Symbols and Punctuation" },
	{ 0x17000, 0x187FF, MIME_UTF8|MIME_NONEU, "Tangut" },
	{ 0x18800, 0x18AFF, MIME_UTF8|MIME_NONEU, "Tangut Components" },
	{ 0x18B00, 0x18CFF, MIME_UTF8|MIME_NONEU, "Khitan Small Script" },
	{ 0x18D00, 0x18D8F, MIME_UTF8|MIME_NONEU, "Tangut Supplement" },
	{ 0x1B000, 0x1B0FF, MIME_UTF8|MIME_NONEU, "Kana Supplement" },
	{ 0x1B100, 0x1B12F, MIME_UTF8|MIME_NONEU, "Kana Extended-A" },
	{ 0x1B130, 0x1B16F, MIME_UTF8|MIME_NONEU, "Small Kana Extension" },
	{ 0x1B170, 0x1B2FF, MIME_UTF8|MIME_NONEU, "Nushu" },
	{ 0x1BC00, 0x1BC9F, MIME_UTF8|MIME_NONEU, "Duployan" },
	{ 0x1BCA0, 0x1BCAF, MIME_UTF8|MIME_NONEU, "Shorthand Format Controls" },
	{ 0x1D000, 0x1D0FF, MIME_UTF8|MIME_NONEU, "Byzantine Musical Symbols" },
	{ 0x1D100, 0x1D1FF, MIME_UTF8|MIME_SYMBOL, "Musical Symbols" },
	{ 0x1D200, 0x1D24F, MIME_UTF8|MIME_SYMBOL, "Ancient Greek Musical Notation" },
	{ 0x1D2E0, 0x1D2FF, MIME_UTF8|MIME_NONEU, "Mayan Numerals" },
	{ 0x1D300, 0x1D35F, MIME_UTF8|MIME_NONEU, "Tai Xuan Jing Symbols" },
	{ 0x1D360, 0x1D37F, MIME_UTF8|MIME_NONEU, "Counting Rod Numerals" },
	{ 0x1D400, 0x1D7FF, MIME_UTF8|MIME_SYMBOL, "Mathematical Alphanumeric Symbols" },
	{ 0x1D800, 0x1DAAF, MIME_UTF8|MIME_SYMBOL, "Sutton SignWriting" },
	{ 0x1E000, 0x1E02F, MIME_UTF8|MIME_NONEU, "Glagolitic Supplement" },
	{ 0x1E100, 0x1E14F, MIME_UTF8|MIME_NONEU, "Nyiakeng Puachue Hmong" },
	{ 0x1E2C0, 0x1E2FF, MIME_UTF8|MIME_NONEU, "Wancho" },
	{ 0x1E800, 0x1E8DF, MIME_UTF8|MIME_NONEU, "Mende Kikakui" },
	{ 0x1E900, 0x1E95F, MIME_UTF8|MIME_NONEU, "Adlam" },
	{ 0x1EC70, 0x1ECBF, MIME_UTF8|MIME_NONEU, "Indic Siyaq Numbers" },
	{ 0x1ED00, 0x1ED4F, MIME_UTF8|MIME_NONEU, "Ottoman Siyaq Numbers" },
	{ 0x1EE00, 0x1EEFF, MIME_UTF8|MIME_SYMBOL, "Arabic Mathematical Alphabetic Symbols" },
	{ 0x1F000, 0x1F02F, MIME_UTF8|MIME_SYMBOL, "Mahjong Tiles" },
	{ 0x1F030, 0x1F09F, MIME_UTF8|MIME_SYMBOL, "Domino Tiles" },
	{ 0x1F0A0, 0x1F0FF, MIME_UTF8|MIME_SYMBOL, "Playing Cards" },
	{ 0x1F100, 0x1F1FF, MIME_UTF8|MIME_SYMBOL, "Enclosed Alphanumeric Supplement" },
	{ 0x1F200, 0x1F2FF, MIME_UTF8|MIME_SYMBOL, "Enclosed Ideographic Supplement" },
	{ 0x1F300, 0x1F5FF, MIME_UTF8|MIME_SYMBOL, "Miscellaneous Symbols and Pictographs" },
	{ 0x1F600, 0x1F64F, MIME_UTF8|MIME_SYMBOL, "Emoticons" },
	{ 0x1F650, 0x1F67F, MIME_UTF8|MIME_SYMBOL, "Ornamental Dingbats" },
	{ 0x1F680, 0x1F6FF, MIME_UTF8|MIME_SYMBOL, "Transport and Map Symbols" },
	{ 0x1F700, 0x1F77F, MIME_UTF8|MIME_SYMBOL, "Alchemical Symbols" },
	{ 0x1F780, 0x1F7FF, MIME_UTF8|MIME_SYMBOL, "Geometric Shapes Extended" },
	{ 0x1F800, 0x1F8FF, MIME_UTF8|MIME_SYMBOL, "Supplemental Arrows-C" },
	{ 0x1F900, 0x1F9FF, MIME_UTF8|MIME_SYMBOL, "Supplemental Symbols and Pictographs" },
	{ 0x1FA00, 0x1FA6F, MIME_UTF8|MIME_SYMBOL, "Chess Symbols" },
	{ 0x1FA70, 0x1FAFF, MIME_UTF8|MIME_SYMBOL, "Symbols and Pictographs Extended-A" },
	{ 0x1FB00, 0x1FBFF, MIME_UTF8|MIME_SYMBOL, "Symbols for Legacy Computing" },
	{ 0x20000, 0x2A6DF, MIME_UTF8|MIME_NONEU, "CJK Unified Ideographs Extension B" },
	{ 0x2A700, 0x2B73F, MIME_UTF8|MIME_NONEU, "CJK Unified Ideographs Extension C" },
	{ 0x2B740, 0x2B81F, MIME_UTF8|MIME_NONEU, "CJK Unified Ideographs Extension D" },
	{ 0x2B820, 0x2CEAF, MIME_UTF8|MIME_NONEU, "CJK Unified Ideographs Extension E" },
	{ 0x2CEB0, 0x2EBEF, MIME_UTF8|MIME_NONEU, "CJK Unified Ideographs Extension F" },
	{ 0x2F800, 0x2FA1F, MIME_UTF8|MIME_NONEU, "CJK Compatibility Ideographs Supplement" },
	{ 0x30000, 0x3134F, MIME_UTF8|MIME_NONEU, "CJK Unified Ideographs Extension G" },
	{ 0xE0000, 0xE007F, MIME_UTF8|MIME_SYMBOL, "Tags" },
	{ 0xE0100, 0xE01EF, MIME_UTF8|MIME_SYMBOL, "Variation Selectors Supplement" },
	{ 0xF0000, 0xFFFFF, MIME_UTF8, "Supplementary Private Use Area-A" },
	{ 0x100000, 0x10FFFF, MIME_UTF8, "Supplementary Private Use Area-B" },
};

const size_t codepoints = sizeof(blocks)/sizeof(unicode_block_t);
